@@ -3,7 +3,7 @@
 set -e
 
 cd debian/tests
-g++ $(pkg-config --cflags --libs systemc) test.cpp
+g++ test.cpp $(pkg-config --cflags --libs systemc)
 ./a.out
 rm -f a.out
 
